==> gnumail_1.0.0.orig.tar.gz: gnumail-1.0.0.orig/Bundles/Sending/SendingViewController.h <==
/*
**  SendingViewController.h
**
**  Copyright (c) 2001
**
**  Author: Ludovic Marcotte <ludovic@Sophos.ca>
**
**  This program is free software; you can redistribute it and/or modify
**  it under the terms of the GNU General Public License as published by
**  the Free Software Foundation; either version 2 of the License, or
**  (at your option) any later version.
**
**  This program is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**  GNU General Public License for more details.
**
**  You should have received a copy of the GNU General Public License
**  along with this program; if not, write to the Free Software
**  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/

#import <AppKit/AppKit.h>

#import "PreferencesModule.h"

@interface SendingViewController : NSObject <PreferencesModule>
{
  // Outlets
  IBOutlet id view;
  
  IBOutlet NSTableView *transportTableView;
  IBOutlet NSTableColumn *transportMethodColumn;
  IBOutlet NSTableColumn *transportValueColumn;

  IBOutlet NSTableView *headerTableView;
  IBOutlet NSTableColumn *headerKeyColumn;
  IBOutlet NSTableColumn *headerValueColumn;

  IBOutlet NSTextField *headerKeyField;
  IBOutlet NSTextField *headerValueField;

  // Other ivars
  NSMutableArray *allSendingValues;
  NSMutableDictionary *allAdditionalHeaders;
}

//
// action methods
//

- (IBAction) addHeader: (id) sender;
- (IBAction) removeHeader: (id) sender;

- (IBAction) addTransportMethod: (id) sender;
- (IBAction) editTransportMethod: (id) sender;
- (IBAction) removeTransportMethod: (id) sender;

@end

==> gnumail_1.1.2.orig.tar.gz: gnumail-1.1.2.orig/Bundles/Sending/SendingViewController.h <==
/*
**  SendingViewController.h
**
**  Copyright (c) 2001, 2002, 2003
**
**  Author: Ludovic Marcotte <ludovic@Sophos.ca>
**
**  This program is free software; you can redistribute it and/or modify
**  it under the terms of the GNU General Public License as published by
**  the Free Software Foundation; either version 2 of the License, or
**  (at your option) any later version.
**
**  This program is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**  GNU General Public License for more details.
**
**  You should have received a copy of the GNU General Public License
**  along with this program; if not, write to the Free Software
**  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/

#ifndef _GNUMail_H_SendingViewController
#define _GNUMail_H_SendingViewController

#import <AppKit/AppKit.h>

#include "PreferencesModule.h"

@interface SendingViewController : NSObject <PreferencesModule>
{
  // Outlets
  IBOutlet id view;

  IBOutlet NSTableView *headerTableView;
  IBOutlet NSTableColumn *headerKeyColumn;
  IBOutlet NSTableColumn *headerValueColumn;

  IBOutlet NSTextField *headerKeyField;
  IBOutlet NSTextField *headerValueField;

  // Values
  struct {
    NSMutableDictionary *allAdditionalHeaders;
  } _values;
}


//
// action methods
//
- (IBAction) addHeader: (id) sender;
- (IBAction) removeHeader: (id) sender;

@end


#endif // _GNUMail_H_SendingViewController
